@@ -11,7 +11,7 @@ def main():
     parser.add_argument('--cogs', action='store_true', help='bootstrap a discord.py bot code with cogs') 
     parser.add_argument('--nocogs', action='store_true', help="bootstrap a discord.py bot code without cogs") 
   
-    if len(sys.argv) < 2:
+    if len(sys.argv) < 2 or sys.argv[2] == "-h" or sys.argv[2] == "-help":
         parser.print_help()
         sys.exit(0)
 
